Getting Started
===============

This section contains tutorials suitable for getting started with CSET. By
following them you should learn the basics of using CSET. It is recommended that
you do them in order. Developers looking to contribute to CSET should see the
:doc:`/contributing/index` section.

.. toctree::
    :maxdepth: 1

    installation
    run-recipe
    visualise-recipe
    create-first-recipe
